#ifndef SEND_GMETRIC_H
#define SEND_GMETRIC_H 1

#ifdef __cplusplus
extern "C" {
#endif

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

/**
 * \file send_gmetric.h
 * This file serves as the library entry point for the libgmetric library.
 */

/**
 * \brief Initialize Ganglia
 * \param conf String containing path to Gmond configuration file
 * \return 0 on success
 */
int init_gmetric(const char* conf);

/**
 * \brief Close connection to gmond
 */
void destroy_gmetric();

/**
 * \brief Send a metric to gmond
 * \param name Name of the metric
 * \param value Value of the metric
 * \param type Type of the metric. Either string|int8|uint8|int16|uint16|int32|uint32|float|double
 * \param units Units of the metric
 * \param slope For RRD, slope to use. Usually "both"
 * \param tmax The maximum time in seconds between gmetric calls
 * \param dmax The lifetime in seconds of this metric
 * \param group Group of the metric
 * \param cluster Cluster for the metric
 * \param desc Description of the metric
 * \param title Title of the metric
 * \return 0 on success
 */
int send_gmetric(const char* name, const char* value, const char* type, const char* units, const char* slope, int tmax,
                 int dmax, const char* group, const char* cluster, const char* desc, const char* title);

#ifdef __cplusplus
}
#endif

#endif
